@@ -35,6 +35,7 @@ pub struct Expression {
     pub expression: String,
 }
 
+#[allow(dead_code)]
 impl Expression {
     fn from_string(string: String) -> Self {
         Self { expression: string }
@@ -104,7 +105,16 @@ impl ChannelCommand {
 
                 args
             }
-            _ => unimplemented!(),
+            ChannelCommand::Ex(ex_command) => {
+                let mut args = Vec::new();
+
+                args.push(DataType::String(ex_command.command.clone()));
+
+                args
+            }
+            ChannelCommand::Unknown => {
+                unimplemented!("This Channel Command is unknown.");
+            }
         }
     }
 }
@@ -116,99 +126,125 @@ impl ChannelCommand {
                 let mut list = self.to_datatypes();
                 list.insert(0, DataType::String("redraw".to_string()));
 
-                let mut string = String::new();
+                let mut buffer = String::new();
 
                 // Start
-                string.push_str("[");
+                buffer.push_str("[");
 
                 // Args
                 for i in list {
-                    string.push_str(&i.to_string());
-                    string.push_str(", ");
+                    buffer.push_str(&i.to_string());
+                    buffer.push_str(", ");
                 }
 
                 // Remove last ", "
-                string.pop();
-                string.pop();
+                buffer.pop();
+                buffer.pop();
 
                 // End
-                string.push_str("]");
+                buffer.push_str("]");
 
-                return string;
+                return buffer;
             }
             ChannelCommand::Normal { .. } => {
                 let mut list = self.to_datatypes();
                 list.insert(0, DataType::String("normal".to_string()));
 
-                let mut string = String::new();
+                let mut buffer = String::new();
 
                 // Start
-                string.push_str("[");
+                buffer.push_str("[");
 
                 // Args
                 for i in list {
-                    string.push_str(&i.to_string());
-                    string.push_str(", ");
+                    buffer.push_str(&i.to_string());
+                    buffer.push_str(", ");
                 }
 
                 // Remove last ", "
-                string.pop();
-                string.pop();
+                buffer.pop();
+                buffer.pop();
 
                 // End
-                string.push_str("]");
+                buffer.push_str("]");
 
-                return string;
+                return buffer;
             }
             ChannelCommand::Call { .. } => {
                 let mut list = self.to_datatypes();
                 list.insert(0, DataType::String("call".to_string()));
 
-                let mut string = String::new();
+                let mut buffer = String::new();
 
                 // Start
-                string.push_str("[");
+                buffer.push_str("[");
 
                 // Args
                 for i in list {
-                    string.push_str(&i.to_string());
-                    string.push_str(", ");
+                    buffer.push_str(&i.to_string());
+                    buffer.push_str(", ");
                 }
 
                 // Remove last ", "
-                string.pop();
-                string.pop();
+                buffer.pop();
+                buffer.pop();
 
                 // End
-                string.push_str("]");
+                buffer.push_str("]");
 
-                return string;
+                return buffer;
             }
             ChannelCommand::Expr { .. } => {
                 let mut list = self.to_datatypes();
                 list.insert(0, DataType::String("expr".to_string()));
 
-                let mut string = String::new();
+                let mut buffer = String::new();
 
                 // Start
-                string.push_str("[");
+                buffer.push_str("[");
 
                 // Args
                 for i in list {
-                    string.push_str(&i.to_string());
-                    string.push_str(", ");
+                    buffer.push_str(&i.to_string());
+                    buffer.push_str(", ");
                 }
 
                 // Remove last ", "
-                string.pop();
-                string.pop();
+                buffer.pop();
+                buffer.pop();
 
                 // End
-                string.push_str("]");
+                buffer.push_str("]");
 
-                return string;
+                return buffer;
+            }
+            ChannelCommand::Ex { .. } => {
+                let mut list = self.to_datatypes();
+                list.insert(0, DataType::String("ex".to_string()));
+
+                let mut buffer = String::new();
+
+                // Start
+                buffer.push_str("[");
+
+                // Args
+                for i in list {
+                    buffer.push_str(&i.to_string());
+                    buffer.push_str(", ");
+                }
+
+                // Remove last ", "
+                buffer.pop();
+                buffer.pop();
+
+                // End
+                buffer.push_str("]");
+
+                return buffer;
+            }
+            ChannelCommand::Unknown => {
+                unimplemented!("This Channel Command is unknown.");
             }
-            _ => unimplemented!(),
         }
     }
 }
@@ -243,18 +279,19 @@ mod tests {
 
     #[test]
     fn test_channel_command_to_string() {
-        // Tests boolean and String DataType Variants
-        //"[\"redraw\", v:true]"
+        // Redraw
         let expected = "[\"redraw\", v:false]";
         let redraw = ChannelCommand::Redraw { forced: false };
         assert_eq!(redraw.to_string(), expected);
 
+        // Normal
         let expected = "[\"normal\", \"gg\"]";
         let normal = ChannelCommand::Normal(NormalCommand {
             command: "gg".to_string(),
         });
         assert_eq!(normal.to_string(), expected);
 
+        // Call
         let expected = "[\"call\", \"getline\", [15], 1]";
         let call = ChannelCommand::Call(
             Call {
@@ -265,6 +302,7 @@ mod tests {
         );
         assert_eq!(call.to_string(), expected);
 
+        // Expression
         let expected = "[\"expr\", \"getline('$')\", 3]";
         let expr = ChannelCommand::Expr(
             Expression {
@@ -273,6 +311,13 @@ mod tests {
             Some(RequestId(3)),
         );
         assert_eq!(expr.to_string(), expected);
+
+        // Ex Command
+        let expected = "[\"ex\", \"call getline('$')\"]";
+        let expr = ChannelCommand::Ex(ExCommand {
+            command: "call getline('$')".to_string(),
+        });
+        assert_eq!(expr.to_string(), expected);
     }
 
     #[test]
